import { Component, OnInit, CUSTOM_ELEMENTS_SCHEMA } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { IonHeader, IonToolbar, IonTitle, IonContent, IonButton, IonIcon, IonBackButton, IonItem, IonLabel, IonInput, IonTextarea, IonButtons } from '@ionic/angular/standalone';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { CloudObject, CloudQuery } from 'src/lib/ncloud';

@Component({
    selector: 'app-art-detail',
    templateUrl: './art-detail.page.html',
    styleUrls: ['./art-detail.page.scss'],
    standalone: true,
    schemas: [CUSTOM_ELEMENTS_SCHEMA],
    imports: [
        CommonModule,
        FormsModule,
        IonHeader,
        IonToolbar,
        IonTitle,
        IonContent,
        IonButton,
        IonIcon,
        IonBackButton,
        IonItem,
        IonLabel,
        IonInput,
        IonTextarea,
        IonButtons
    ]
})
export class ArtDetailPage implements OnInit {
    artDetail: any = {};
    comments: any[] = [];
    newComment: string = '';
    isLiked: boolean = false;
    likeCount: number = 0;

    constructor(private route: ActivatedRoute) { }

    ngOnInit() {
        const id = this.route.snapshot.paramMap.get('id');
        if (id) {
            this.loadArtDetail(id);
            this.loadComments(id);
        }
    }

    async loadArtDetail(id: string) {
        const query = new CloudQuery('ArtWork');
        const result = await query.get(id);
        this.artDetail = result;
        this.likeCount = result['get']('likes') || 0;
        this.checkLikeStatus();
    }

    async loadComments(artId: string) {
        const query = new CloudQuery('Comments');
        query.equalTo('artId', artId);
        const results = await query.find();
        this.comments = results || [];
    }

    async toggleLike() {
        if (!this.isLiked) {
            this.likeCount++;
            this.isLiked = true;
            this.artDetail.set('likes', this.likeCount);
            await this.artDetail.save();
        }
    }

    async addComment() {
        if (!this.newComment.trim()) return;

        const comment = new CloudObject('Comments');
        // comment.set('artId', this.artDetail.id);
        // comment.set('content', this.newComment);
        // comment.set('createdAt', new Date());
        await comment.save();

        await this.loadComments(this.artDetail.id);
        this.newComment = '';
    }

    private async checkLikeStatus() {
        // 这里可以添加检查用户是否已点赞的逻辑
        // 可以使用 localStorage 或者数据库来存储用户的点赞状态
    }
} 